<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fresh-left/css/style.css */
class __TwigTemplate_285d18d3580aaedd30e9ab4986b116fb extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "/* Normalize */
article,aside,details,figcaption,figure,footer,header,hgroup,main,nav,section,summary{display:block}
audio,canvas,video{display:inline-block}
audio:not([controls]){display:none;height:0}
[hidden]{display:none}
html{font-family:sans-serif;-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%}
body{margin:0}
a:focus{outline:thin dotted}
a:active,a:hover{outline:0}
h1{font-size:2em;margin:0.67em 0}
abbr[title]{border-bottom:1px dotted}
b,strong{font-weight:bold}
dfn{font-style:italic}
hr{-moz-box-sizing:content-box;box-sizing:content-box;height:0}
mark{background:#ff0;color:#000}
code,kbd,pre,samp{font-family:monospace, serif;font-size:1em}
pre{white-space:pre-wrap}
q{quotes:\"\\201C\" \"\\201D\" \"\\2018\" \"\\2019\"}
small{font-size:80%}
sub,sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline}
sup{top:-0.5em}
sub{bottom:-0.25em}
img{border:0}
svg:not(:root){overflow:hidden}
figure{margin:0}
fieldset{border:1px solid #c0c0c0;margin:0 2px;padding:0.35em 0.625em 0.75em}
legend{border:0;padding:0}
button,input,select,textarea{font-family:inherit;font-size:100%;margin:0}
button,input{line-height:normal}
button,select{text-transform:none}
button,html input[type=\"button\"],input[type=\"reset\"],input[type=\"submit\"]{-webkit-appearance:button;cursor:pointer}
button[disabled],html input[disabled]{cursor:default}
input[type=\"checkbox\"],input[type=\"radio\"]{box-sizing:border-box;padding:0}
input[type=\"search\"]{-webkit-appearance:textfield;-moz-box-sizing:content-box;-webkit-box-sizing:content-box;box-sizing:content-box}
input[type=\"search\"]::-webkit-search-cancel-button,input[type=\"search\"]::-webkit-search-decoration{-webkit-appearance:none}
button::-moz-focus-inner,input::-moz-focus-inner{border:0;padding:0}
textarea{overflow:auto;vertical-align:top}
table{border-collapse:collapse;border-spacing:0}

/* Clearfix */
.container:before,.container:after,.clearfix:before,.clearfix:after{content:'';display:table}
.container:after,.clearfix:after{clear:both}
.container,.clearfix{zoom:1}

/* Gridiculous */
*{-webkit-box-sizing:border-box;-moz-box-sizing:border-box;-ms-box-sizing:border-box;box-sizing:border-box}
body{font-size:100%;line-height:1.6875}
img{max-width:100%;height:auto;display:block;}
.wfull{width:100%;max-width:100%}
.w320{max-width:31rem}
.w640{max-width:640px}
.w960{max-width:73rem}
.c1{width:8.33%}
.c2{width:16.66%}
.c3{width:25%}
.c4{width:33.33%}
.c5{width:41.66%}
.c6{width:50%}
.c7{width:58.33%}
.c8{width:66.66%}
.c9{width:75%}
.c10{width:83.33%}
.c11{width:91.66%}
.c12{width:100%}
.c1,.c2,.c3,.c4,.c5,.c6,.c7,.c8,.c9,.c10,.c11,.c12{min-height:1px;float:left;position:relative}
.s1{margin-left:8.33%}
.s2{margin-left:16.66%}
.s3{margin-left:25%}
.s4{margin-left:33.33%}
.s5{margin-left:41.66%}
.s6{margin-left:50%}
.s7{margin-left:58.33%}
.s8{margin-left:66.66%}
.s9{margin-left:75%}
.s10{margin-left:83.33%}
.s11{margin-left:91.66%}
.end{float:right!important}

/* Media query for 960 Screens - sets nested grids to 100% */
@media only screen and (max-width:73rem){
.container .container .c1,.container .container .c2,.container .container .c3,.container .container .c4,.container .container .c5,.container .container .c6,.container .container .c7,.container .container .c8,.container .container .c9,.container .container .c10,.container .container .c11,.container .container .c12{width:100%;margin-bottom:1rem}
.container .container > div:last-child{margin-bottom:0 !important}
.container {padding: 3rem 2rem !important;}
.form-container {width: 100%; margin: 0;}
.form {max-width: 100% !important;}
.hero {padding-top: 4rem;}
.speakers-container, .testimonials-container, .grid-container {display: block !important;}
.speaker, .testimonial, .grid-item {display: block; float: left; margin: 0 0 2rem 0 !important; width: 100%;}
}

/* Media query for iPad and tablets */
@media handheld, only screen and (max-width: 48rem), only screen and (max-device-width: 48rem) and (orientation:portrait){
body{font-size:90%}
.container{margin-bottom:0!important; padding: 2rem 1.5rem !important;}
.c1,.c2,.c3,.c4,.c5,.c6,.c7,.c8,.c9,.c10,.c11,.c12{width:100%;margin-right:0;margin-left:0;margin-bottom:1rem}
}

/* Additional helpers */
.no-padding {padding: 0 !important;}
.hide {display: none;}
.txtCenter, .txtCenter .subheader-titles {text-align: center !important;}
.green {
  color: #00bf9a;
}

/* LP Builder helpers */
div[data-section-wrapper], div[data-section], div[data-slot-container], div[data-slot] {
  position: relative;
  z-index: 1;
}

div[data-section-focus] {
  z-index: 2;
}


/* Page Styling */
section[style=\"background-color: #00bf9a;\"] {
  color: #ffffff;
}
section[style=\"background-color: #00bf9a;\"]  + section[style=\"background-color: #00bf9a;\"] .container {
  border-top: 1px solid #ffffff;
}
.charcoal {
  color: #3f3f45;
}
section[style=\"background-color: #3f3f45;\"] {
  color: #ffffff;
}
section[style=\"background-color: #3f3f45;\"]  + [style=\"background-color: #3f3f45;\"]  .container {
  border-top: 1px solid #636363;
}
.white {
  color: #ffffff;
}
section[style=\"background-color: #f5f5f5;\"] {
  color: #212121;
}
section[style=\"background-color: #f5f5f5;\"] + section[style=\"background-color: #f5f5f5;\"] .container {
  border-top: 1px solid #DEDEDE;
}
/* Opens sans font */
@font-face {
  font-family: 'Open Sans';
  src: url('open-sans/OpenSans-Light.WOFF') format('woff'),
       url('open-sans/OpenSans-Light.ttf')  format('truetype'); 
  font-weight: 100;
}
@font-face {
  font-family: 'Open Sans';
  src: url('open-sans/OpenSans-LightItalic.WOFF') format('woff'),
       url('open-sans/OpenSans-LightItalic.ttf')  format('truetype'); 
  font-weight: 100;
  font-style: italic;
}
@font-face {
  font-family: 'Open Sans';
  src: url('open-sans/OpenSans-Regular.WOFF') format('woff'),
       url('open-sans/OpenSans-Regular.ttf')  format('truetype'); 
  font-weight: 300;
}
@font-face {
  font-family: 'Open Sans';
  src: url('open-sans/OpenSans-Italic.WOFF') format('woff'),
       url('open-sans/OpenSans-Italic.ttf')  format('truetype'); 
  font-weight: 300;
  font-style: italic;
}
@font-face {
  font-family: 'Open Sans';
  src: url('open-sans/OpenSans-SemiBold.WOFF') format('woff'),
       url('open-sans/OpenSans-SemiBold.ttf')  format('truetype'); 
  font-weight: 500;
}
@font-face {
  font-family: 'Open Sans';
  src: url('open-sans/OpenSans-SemiBoldItalic.WOFF') format('woff'),
       url('open-sans/OpenSans-SemiBoldItalic.ttf')  format('truetype'); 
  font-weight: 500;
  font-style: italic;
}
@font-face {
  font-family: 'Open Sans';
  src: url('open-sans/OpenSans-Bold.WOFF') format('woff'),
       url('open-sans/OpenSans-Bold.ttf')  format('truetype'); 
  font-weight: 700;
}
@font-face {
  font-family: 'Open Sans';
  src: url('open-sans/OpenSans-BoldItalic.WOFF') format('woff'),
       url('open-sans/OpenSans-BoldItalic.ttf')  format('truetype'); 
  font-weight: 700;
  font-style: italic;
}

/* Button style */
.button {
  display: inline-block;
  padding: 1rem 1.75rem;
  border-radius: .25rem;
  text-transform: uppercase;
  font-size: .9rem;
  font-weight: 600;
  text-decoration: none;
  position: relative;
  letter-spacing: .02rem;
  cursor: pointer;
  margin: 0 .5rem;
  overflow: hidden;
  border: 1px solid #ffffff;
  -webkit-box-shadow: -2px 2px 2px 0 rgba(0,0,0,.2);
  -moz-box-shadow: -2px 2px 2px 0 rgba(0,0,0,.2);
  box-shadow: -2px 2px 2px 0 rgba(0,0,0,.2);
  -webkit-transition: all 1s cubic-bezier(.19,1,.22,1);
  transition: all 1s cubic-bezier(.19,1,.22,1);
  background: #ffffff;
  color: #212121;
}

.button:hover {
  background: transparent;
  color: #ffffff;
  -webkit-box-shadow: -2px 2px 2px 0 rgba(0,0,0,.6);
  -moz-box-shadow: -2px 2px 2px 0 rgba(0,0,0,.6);
  box-shadow: -2px 2px 2px 0 rgba(0,0,0,.6);
}

/* Page style */
* {
  font-family: \"Open Sans\", verdana, sans-serif;
}
body {
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
p, span, h1, h2, h3, h4, h5, h6, ul, li {
  float: left;
  width: 100%;
  margin: 0;
}
.container p, .container span, .container ul, .container li {
  float: none;
  margin: 0;
}
.container h1, .container h2, .container h3, .container h4, .container h5, .container h6 {
  margin-bottom: 0.25rem;
}
p {
  margin: 0;
  font-weight: 300;
}
header {
  position: fixed;
  text-align: left;
  z-index: 2;
  background: rgba(63,63,69,0.33);
  top: 0;
  left: 0;
  right: 0;
  width: 100%;
  height: 4.5rem;
  padding: 0.75rem 0;
  -webkit-transition: all 0.2s cubic-bezier(.19, 1, .22, 1);
  transition: all 0.2s cubic-bezier(.19, 1, .22, 1);
}
header .logo {
  height: 3rem;
  display: inline-block;
  -webkit-transition: all 0.2s cubic-bezier(.19, 1, .22, 1);
  transition: all 0.2s cubic-bezier(.19, 1, .22, 1);
}
header .container {
  padding: 0;
}
@media (max-width:73rem) {
  header .container {
    padding: 0 2rem !important;
  }
}
@media (max-width:48rem) {
  header .container {
    padding: 0 1.5rem !important;
  }
}
header.scroll {
  height: 3.5rem;
  background: rgba(63,63,69,0.66);
}
header.scroll .logo {
  height: 2rem;
}
footer .logo {
  height: 2rem;
  display: inline-block;
}
footer {
  background: #109f85;
  float: left;
  width: 100%;
}
footer .container {
  padding: 0.75rem 0;
}
footer .logo {
  float: left;
}
footer .copyright {
  text-align: right;
  color: #ffffff;
}
@media (max-width:48rem) {
  footer p {
    text-align: center;
  }
  footer .copyright {
    text-align: center;
  }
  footer {
    text-align: center;
  }
  footer .logo-container {
    text-align: center;
  }
  footer .logo {
    float: none;
  }
}

section {
  float: left;
  width: 100%;
  padding: 0;
  overflow: hidden;
}
.container {
  width: 100%;
  max-width: 73rem;
  margin: 0 auto;
  padding: 6rem 0;
}

.container h2 {
  margin: 0 0 1rem 0;
}

/* Hero Style */

.hero {
  overflow: hidden;
  position: relative;
}

.hero p {
  margin-bottom: 1.5rem;
}

.hero .form h2 {
  color: #00bf9a;
}

.hero .background {
  position: absolute;
  width: 100%;
  height: 100%;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  min-height: 10rem;
}

.hero .background div[data-slot-container], .hero .background div[data-slot] {
  position: absolute;
  width: 100%;
  height: 100%;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  min-height: 10rem;
}

.hero .background-image {
  object-fit: contain;
  width: 120%;
  margin: -10%;
  opacity: 0.3;
  max-width: 120%;
}

@media (max-width: 73rem) {
  .hero .background-image {
    height: 120%;
    max-width: inherit;
    width: auto;
    margin: calc(-20% - 3rem);
  }
}

.hero .container {
  padding: 4.5rem 0 0 0;
}

.hero-details {
  padding: 6rem 0 6rem 3rem;
  color: #ffffff;
  float: left;
  width: 100%;
}

@media (max-width: 73rem) {
  .hero-details {
    padding: 3rem 0;
  }
  .hero-details-container {
    width: 100%;
  }
}

/* Form style */
.form {
    padding: 3.5rem 2.3rem;
    float: left;
    -webkit-box-shadow: -3px 3px 4px 0 rgba(0, 0, 0, .2);
    -moz-box-shadow: -3px 3px 4px 0 rgba(0, 0, 0, .2);
    box-shadow: -3px 3px 4px 0 rgba(0, 0, 0, .2);
    max-width: 40rem;
    width: 100%;
}

.form h1,
.form p {
    padding: 0 0 0 .8rem;
    margin: 0 0 2rem;
    float: left
}

.form h1 {
    line-height: 2.2rem;
    font-size: 1.8rem;
    width: 50%;
    height: 3.75rem
}

@media (max-width:48rem) {
  .form {
    padding: 3.5rem 1rem;
  }
}

.form p {
    font-size: 1rem;
    line-height: 1.8rem;
    opacity: .75;
    width: 50%;
    height: 3.75rem
}

@media (max-width:73rem) {
    .form p {
        width: 100%;
        height: auto
    }
}

.form a {
    color: #40DA9F;
    -webkit-transition: all 1s cubic-bezier(.19, 1, .22, 1);
    transition: all 1s cubic-bezier(.19, 1, .22, 1);
    display: inline
}

.form a:hover {
    color: #fff
}

.form button,
.form input,
.form select,
.form textarea {
    border: none;
    border-radius: 0;
    -webkit-appearance: none;
    -moz-appearance: none;
    color: #fffff;
    height: 2.4rem;
    font-weight: 500;
    width: 100%;
    background: rgba(144, 167, 188, .7);
    outline: 0;
    padding: 0 1rem;
    -webkit-transition: all 1s cubic-bezier(.19, 1, .22, 1);
    transition: all 1s cubic-bezier(.19, 1, .22, 1)
}

.form button:hover,
.form input:hover,
.form select:hover,
.form textarea:hover {
    background: rgba(144, 167, 188, .9)
}

.form button:focus,
.form input:focus,
.form select:focus,
.form textarea:focus {
    color: #212121;
    background: #90a7bc
}

.form button::-webkit-input-placeholder,
.form input::-webkit-input-placeholder,
.form select::-webkit-input-placeholder,
.form textarea::-webkit-input-placeholder {
    color: #fff
}

.form button::-moz-placeholder,
.form input::-moz-placeholder,
.form select::-moz-placeholder,
.form textarea::-moz-placeholder {
    color: #fff
}

.form button:-ms-input-placeholder,
.form input:-ms-input-placeholder,
.form select:-ms-input-placeholder,
.form textarea:-ms-input-placeholder {
    color: #fff
}

.form button:-moz-placeholder,
.form input:-moz-placeholder,
.form select:-moz-placeholder,
.form textarea:-moz-placeholder {
    color: #fff
}

.form select {
    color: #fff;
    background: url(../assets/icon_arrow-down_white.svg), rgba(144, 167, 188, .7);
    background-size: .55rem auto;
    background-position: 95%, center;
    background-repeat: no-repeat
}

.form select:hover {
    background: url(../assets/icon_arrow-down_white.svg), rgba(144, 167, 188, .9);
    background-size: .55rem auto;
    background-position: 95%, center;
    background-repeat: no-repeat
}

.form select:focus {
    background: url(../assets/icon_arrow-down_white.svg) 95% no-repeat, center no-repeat #90a7bc;
    background-size: .55rem auto
}

.form input[type=checkbox],
.form input[type=radio] {
    -webkit-appearance: none;
    height: 2em;
    width: 2em;
    margin: -.05rem .5rem 0 0;
    cursor: pointer;
    position: relative;
    -webkit-transition: all 1s cubic-bezier(.19, 1, .22, 1);
    transition: all 1s cubic-bezier(.19, 1, .22, 1);
    border-radius: 2em;
    outline: 0;
    padding: 0 .8rem
}

.form input[type=checkbox]:checked,
.form input[type=radio]:checked {
    background-color: #40DA9F
}

.form input[type=checkbox]:before,
.form input[type=checkbox]:checked:before,
.form input[type=radio]:before,
.form input[type=radio]:checked:before {
    position: absolute;
    top: 32%;
    left: 35%;
    width: 30%;
    height: 30%;
    text-align: center;
    color: #fff;
    content: '';
    line-height: .5rem;
    background: 0 0!important
}

.form input[type=checkbox]:checked:before,
.form input[type=radio]:checked:before {
    content: url(../assets/icon_check_blue.svg)
}

.form input[type=checkbox]:hover:before,
.form input[type=radio]:hover:before {
    background: rgba(255, 255, 255, .3)
}

.form .mauticform-checkboxgrp-label,
.form .mauticform-radiogrp-row label {
    text-transform: none;
    font-size: .8rem;
    font-weight: 600;
    line-height: 1.6rem
}

.form label,
.form label.mauticform-label {
    font-size: .75rem!important;
    font-weight: 400!important;
    margin-bottom: .5rem!important;
    text-transform: uppercase
}

.form label span,
.form label.mauticform-label span {
    width: 70%;
    display: inline-block;
    vertical-align: middle
}

.form label,
.form label * {
    display: inline-block;
    vertical-align: middle;
    line-height: 1rem
}

.form button.mauticform-pagebreak {
    position: relative;
    margin-top: .5rem!important;
    margin-left: calc(50% - 8rem)!important;
    margin-right: calc(50% - 8rem)!important;
    margin-bottom: 0!important
}

.form button.mauticform-pagebreak.mautic-pagebreak-back {
    background: 0 0!important;
    color: #fff!important;
    -webkit-box-shadow: none!important;
    -moz-box-shadow: none!important;
    box-shadow: none!important;
    height: 2rem!important;
    font-weight: 400!important
}

.form button.mauticform-pagebreak~.mauticform-button-wrapper {
    margin-top: 0!important
}

.form.thank-you h1,
.form.thank-you p {
    width: 100%;
    height: auto
}

.form.thank-you h1 {
    margin: 0 0 .5rem
}

.form .mauticform-required:after {
    content: '*';
    position: absolute;
    top: 1rem;
    right: 1rem;
    line-height: .9rem;
    font-size: 1rem
}

.form.white,
.form.white label {
    color: #212121
}

.form.white {
    background: #fff
}

.form.white input,
.form.white select,
.form.white textarea {
    background: #f4f3f3;
    color: #212121;
    border-bottom: 1px solid;
    border-color: rgba(33, 33, 33, .1);
    font-size: .9rem
}

.form.white input:hover,
.form.white select:hover,
.form.white textarea:hover {
    background: #fff
}

.form.white input::-webkit-input-placeholder,
.form.white select::-webkit-input-placeholder,
.form.white textarea::-webkit-input-placeholder {
    color: #212121
}

.form.white input::-moz-placeholder,
.form.white select::-moz-placeholder,
.form.white textarea::-moz-placeholder {
    color: #212121
}

.form.white input:-ms-input-placeholder,
.form.white select:-ms-input-placeholder,
.form.white textarea:-ms-input-placeholder {
    color: #212121
}

.form.white input:-moz-placeholder,
.form.white select:-moz-placeholder,
.form.white textarea:-moz-placeholder {
    color: #212121
}

.form.white .privacy a:hover,
.form.white label a:hover {
    color: #00bf9a
}

.form.white label a {
    color: #00bf9a;
    font-weight: 700
}

.form.white .privacy a {
    font-weight: 700
}

.form.white .mauticform-required:after {
    color: rgba(33, 33, 33, .2)
}

.form .panel {
    float: left;
    padding: 2rem 1.5rem;
    left: -4.5rem;
    width: calc(100% + 9.1rem);
    margin: 0 0 2.25rem
}

.form .panel p {
    margin: 0;
    position: relative;
    z-index: 3
}

.form .panel a {
    color: #4e5e9e;
    font-weight: 600
}

.form .panel a:hover {
    color: #1E5D86
}

.form .button,
.form .mauticform-button-wrapper .mauticform-button,
.form button,
.form button.btn.btn-default {
    background: #00bf9a;
    color: #fff;
    border: none;
    border-width: 0;
    max-width: 16rem;
    display: inline-block;
    border-radius: 2rem;
    padding: .8rem 1rem;
    width: 100%;
    height: auto;
    text-align: center;
    -webkit-transition: all 1s cubic-bezier(.19, 1, .22, 1);
    transition: all 1s cubic-bezier(.19, 1, .22, 1);
    -webkit-box-shadow: -2px 2px 2px 0 rgba(0, 0, 0, .2);
    -moz-box-shadow: -2px 2px 2px 0 rgba(0, 0, 0, .2);
    box-shadow: -2px 2px 2px 0 rgba(0, 0, 0, .2)
}

.form .button:hover,
.form .mauticform-button-wrapper .mauticform-button:hover,
.form button.btn.btn-default:hover,
.form button:hover {
    -webkit-transition: all 1s cubic-bezier(.19, 1, .22, 1);
    transition: all 1s cubic-bezier(.19, 1, .22, 1);
    color: #ffffff;
    -webkit-box-shadow: -2px 2px 2px 0 rgba(0, 0, 0, .5);
    -moz-box-shadow: -2px 2px 2px 0 rgba(0, 0, 0, .5);
    box-shadow: -2px 2px 2px 0 rgba(0, 0, 0, .5)
}

.form .button#mauticform_input_mauticcomsignupfree_final_page,
.form .mauticform-button-wrapper .mauticform-button#mauticform_input_mauticcomsignupfree_final_page,
.form button#mauticform_input_mauticcomsignupfree_final_page,
.form button.btn.btn-default#mauticform_input_mauticcomsignupfree_final_page {
    color: #fff;
    background: #1E2A36
}

.form .button#mauticform_input_mauticcomsignupfree_final_page:hover,
.form .mauticform-button-wrapper .mauticform-button#mauticform_input_mauticcomsignupfree_final_page:hover,
.form button#mauticform_input_mauticcomsignupfree_final_page:hover,
.form button.btn.btn-default#mauticform_input_mauticcomsignupfree_final_page:hover {
    background: #11181F
}

.form .mauticform-errormsg {
    height: 2rem;
    float: left;
    color: #FF6363;
    font-weight: 600;
    font-size: .76rem;
    line-height: 1rem;
    padding: .4rem 0 0
}

.form .mauticform-freetext {
    width: 100%
}

.form .mauticform-freetext span {
    font-size: 1.2rem!important;
    line-height: 1.9rem!important
}

.form .mauticform-freetext a {
    color: #00bf9a!important
}

.form .privacy {
    width: 100%;
    float: left;
    text-align: center;
    text-transform: uppercase;
    font-size: .65rem;
    letter-spacing: .1rem;
    font-weight: 500
}

.mauticform-row {
    width: 50%;
    float: left;
    padding: .75rem .9rem;
    margin-bottom: 0!important;
    position: relative
}

@media (min-width:73rem) {
  .mauticform-row:nth-child(odd) {
    padding-left: 0;
  }

  .mauticform-row:nth-child(even) {
    padding-right: 0;
  }
}

.mauticform-row#mauticform_contactus_message {
    width: 100%
}

.mauticform-row#mauticform_contactus_message textarea {
    height: 7rem
}

.mauticform-row.mauticform-has-error,
.mauticform-row.mauticform-has-error+.mauticform-row {
    min-height: 7.5rem
}

.mauticform-pagebreak-wrapper,
.mauticform-row.mauticform-button-wrapper {
    width: 100%;
    text-align: center;
    margin: 1rem 0 0
}

@media (max-width:48rem) {
    .mauticform-row {
        width: 100%;
        padding: .75rem 0;
    }
}

.form .mauticform-row.mauticform-required .mauticform-label:after {
  color: #fff;
  line-height: .75rem;
  vertical-align: bottom;
  content: ' *';
  position: absolute;
  right: 1.6rem;
  top: 3.3rem;
  display: none
}

input[type=text] {
    border: none;
    border-radius: 0;
    -webkit-appearance: none;
    height: 2.4rem;
    font-weight: 500;
    width: 100%;
    background: rgba(144, 167, 188, .7);
    outline: 0;
    padding: 0 1rem;
    -webkit-transition: all 1s cubic-bezier(.19, 1, .22, 1);
    transition: all 1s cubic-bezier(.19, 1, .22, 1)
}

input[type=text]:hover {
    background: rgba(144, 167, 188, .9)
}

input[type=text]:focus {
    color: #212121
}

input[type=text]::-webkit-input-placeholder {
    color: #fff
}

input[type=text]::-moz-placeholder {
    color: #fff
}

input[type=text]:-ms-input-placeholder {
    color: #fff
}

input[type=text]:-moz-placeholder {
    color: #fff
}

input:focus {
    background: rgba(255, 255, 255, .7)
}

body .facetwp-btn {
    right: .75rem
}

/* Customer section */
.customers {
  float: left;
  width: 100%;
  color: #212121;
  background: #ffffff;
  padding: 2rem 2rem 1.5rem 2rem;
  -webkit-box-shadow: -3px 3px 4px 0 rgba(0, 0, 0, .2);
  -moz-box-shadow: -3px 3px 4px 0 rgba(0, 0, 0, .2);
  box-shadow: -3px 3px 4px 0 rgba(0, 0, 0, .2);
}
.customers .container {
  padding: 3.5rem 0;
}

.customers .logo-container {
  display: inline-block;
  margin-right: 1.5rem;
  line-height: 3rem;
  width: 8rem;
}
@media (max-width: 73rem) {
  .customers .logo-container {
    width: auto;
    flex: 1;
  }
  .customers {
    overflow: auto;
  }
  .customers .logos {
    text-align: left;
    display: flex;
    flex-direction: row;
    display: -webkit-box;
    display: -webkit-flex;
    display: flex;
    -webkit-box-align: center;
    -webkit-align-items: center;
    -webkit-box-pack: center;
    -webkit-justify-content: left;
    justify-content: left;
    align-items: stretch;
    width: 100%;
    min-width: 73rem;
  }
  .customers .logo {
    width: 10rem;
    height: auto;
    flex: 1;
    display: inline-block;
    filter: grayscale(100%);
    -webkit-transition: all 1s cubic-bezier(.19,1,.22,1);
    transition: all 1s cubic-bezier(.19,1,.22,1);
  }
}

.customers .logo {
  width: 10rem;
  height: auto;
  display: inline-block;
  filter: grayscale(100%);
  -webkit-transition: all 1s cubic-bezier(.19,1,.22,1);
  transition: all 1s cubic-bezier(.19,1,.22,1);
}

.customers .logo:hover {
  filter: grayscale(0%);
}

/* Details */
.details .container {
  padding: 3.5rem 0;
}

/* Speaker section */
.speakers .speakers-container {
  display: flex;
  flex-direction: row;
  display: -webkit-box;
  display: -webkit-flex;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  justify-content: center;
  align-items: stretch;
  width: 100%;
}

.speaker {
  background: #3f3f45;
  color: #ffffff;
  margin: 0 0.5rem;
  flex: 1;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}

.speaker h3 {
  color: #00bf9a;
}

.speaker .speaker-details {
  width: calc(100% - 16rem);
}

.speaker-image img {
  border-radius: 50%;
}
.speaker-image {
  padding: 2rem;
  width: 16rem;
}
.speaker:first-child {
  margin-left: 0;
}
.speaker:last-child {
  margin-right: 0;
}

@media (max-width:48rem) {
    .speaker {
      display: block !important;
    }
    .speaker .speaker-details {
      width: 100%;
      padding: 0 2rem 2rem 2rem;
      text-align: center;
    }
    .speaker-image {
      width: 100%;
      text-align: center;
      padding-bottom: 1rem;
    }
    .speaker-image img {
      display: inline-block;
    }
}


/* Grid section */
.grid .grid-container {
  display: flex;
  flex-direction: row;
  display: -webkit-box;
  display: -webkit-flex;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  justify-content: center;
  align-items: stretch;
  width: 100%;
  margin-bottom: 0.2rem;
}

.grid .grid-item {
  background: rgba(255,255,255,0.1);
  text-align: center;
  padding: 3rem 1.5rem;
  margin-right: 0.2rem;
  flex: 1;
  overflow: hidden;
  position: relative;
  margin: 0 0.1rem;
}

.grid-item .grid-background-image {
  position: absolute;
  z-index: 0;
  object-fit: contain;
  max-width: 150%;
  width: 150%;
  top: -10%;
  bottom: -10%;
  left: -10%;
  right: -10%;
}

.grid-item h3 {
  margin: 0;
}

.grid-item * {
  position: relative;
  z-index: 1;
  color: #ffffff;
}

.grid-item:first-child {
  margin-left: 0;
}

.grid-item:last-child {
  margin-right: 0;
}

.grid-item .icon {
  height: 2.5rem;
  display: inline-block;
  margin: 0 0 0.75rem 0;
}

/* Testimonials section */
.testimonials .testimonials-container {
  display: flex;
  flex-direction: row;
  display: -webkit-box;
  display: -webkit-flex;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  justify-content: center;
  align-items: stretch;
  width: 100%;
  margin-bottom: 0.2rem;
}

.testimonial-details {
  width: 100%;
  max-width: 36rem;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}

@media (max-width:48rem) {
    .testimonial-details {
      display: block !important;
    }
}

.testimonial-quote:before {
  content: '▼';
  width: 1rem;
  height: 1rem;
  left: 1.5rem;
  bottom: -0.4rem;
  position: absolute;
  transform: scale(1.5, 1);
  -webkit-transform: scale(1.5, 1);
  -moz-transform: scale(1.5, 1);
  -o-transform: scale(1.5, 1);
  -ms-transform: scale(1.5, 1);
  color: #ffffff;
}

.testimonial {
  margin: 0.5rem;
}

.testimonial h3 {
  color: #00bf9a;
}

.testimonial:first-child {
  margin-left: 0;
}
.testimonial:last-child {
  margin-right: 0;
}

.testimonials .testimonial {
  flex: 1;
}

.testimonials .speaker-image {
  padding-left: 0;
}

@media (max-width:48rem) {
  .testimonials .speaker-image {
    display: inline-block !important;
  }
  .testimonial-details {
    text-align: center;
  }
  .testimonials .speaker-image {
    padding-left: 2rem;
    padding-bottom: 0;
    width: auto;
  }
  .testimonial-quote:before {
    left: 0;
    right: 0;
    margin: 0 auto;
  }
}

.testimonials .testimonial-quote {
  background: #ffffff;
  color: #3f3f45;
  padding: 3rem 1.5rem;
}

/* Thank You Section */
.thank-you .button {
  margin: 1.5rem 0 0 0;
}

.thank-you h1, .thank-you p {
  color: #ffffff;
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fresh-left/css/style.css";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fresh-left/css/style.css", "/var/www/html/mauticGIT-Test/themes/fresh-left/css/style.css");
    }
}
